@@ -499,10 +499,12 @@ def buildInstrumentList(instrumentNameString: str, parentRQLClassName: str = '',
     psb.setImport(setPath,'',True,'set'+c_instrumentNameString+'List')
     parentClassList.append('set'+c_instrumentNameString+'List')
     psb.startClass(instrumentNameString+'List',parentClassList)
+    psb.code.add_line("elementClass = " + RQLpathObj.classNameDict[c_instrumentNameString])
 
     if parentRQLClassName == '':# add self.__init__ to independent class
         psb.startFunction('__init__')
         psb.code.add_line('self.all = []')
+        psb.code.add_line("self.listType = '" + securityType + " List'")
         psb.endFunction()
     elif type(parentRQLClassName) == type(''):
         psb.startFunction('__init__')
@@ -633,7 +635,7 @@ def buildInstrument(instrumentNameString:str, parentRQLClassName:str = '', paren
     None
 
     """
-    pathList = buildInstrumentPath(instrumentNameString, parentRQLClassName=parentRQLClassName)
+    pathList = buildInstrumentPath(instrumentNameString, parentRQLClassName=parentRQLClassName,targetProjectPath=targetProjectPath)
     IO = buildInstrumentObj(instrumentNameString, parentRQLClassName, parentQuantLibClassName, libraryName, defaultInstrumentType)
     IOS = buildInstrumentSet(instrumentNameString, parentRQLClassName)
     IL = buildInstrumentList(instrumentNameString, parentRQLClassName,defaultInstrumentType)
@@ -641,7 +643,7 @@ def buildInstrument(instrumentNameString:str, parentRQLClassName:str = '', paren
     if targetProjectPath == '':
         [commitBuildInstrument(source, path) for path, source in zip(pathList, [IO, IOS, IL, ILS])]
     else:
-        [commitBuildInstrument(source,targetProjectPath + os.sep + path.split('RiskQuantLib')[-1]) for path,source in zip(pathList,[IO,IOS,IL,ILS])]
+        [commitBuildInstrument(source,targetProjectPath + os.sep +'RiskQuantLib'+os.sep+ path.split('RiskQuantLib')[-1]) for path,source in zip(pathList,[IO,IOS,IL,ILS])]
 
     return None
 
