@@ -1,14 +1,15 @@
 #!/usr/bin/python
 #coding = utf-8
 
-from RiskQuantLib.IndexList.base import base
+from RiskQuantLib.IndexList.base import baseList
 from RiskQuantLib.Index.BondIndex.bondIndex import bondIndex
 from RiskQuantLib.Set.IndexList.BondIndexList.bondIndexList import setBondIndexList
 
-class bondIndexList(base,setBondIndexList):
+class bondIndexList(baseList,setBondIndexList):
     """
     This class is the list of bond index.
     """
+    elementClass = bondIndex
     def __init__(self):
         super(bondIndexList, self).__init__()
         self.listType = 'Bond Index List'
