@@ -2,14 +2,15 @@
 #coding = utf-8
 
 
-from RiskQuantLib.IndexList.base import base
+from RiskQuantLib.IndexList.base import baseList
 from RiskQuantLib.Index.StockIndex.stockIndex import stockIndex
 from RiskQuantLib.Set.IndexList.StockIndexList.stockIndexList import setStockIndexList
 
-class stockIndexList(base,setStockIndexList):
+class stockIndexList(baseList,setStockIndexList):
     """
     This class is the list of stock index.
     """
+    elementClass = stockIndex
     def __init__(self):
         super(stockIndexList, self).__init__()
         self.listType = 'Stock Index List'
