@@ -5,12 +5,14 @@ from QuantLib import Index
 from RiskQuantLib.Set.IndexList.base import setBase
 from RiskQuantLib.Operation.listBaseOperation import listBase
 
-class base(Index,setBase,listBase):
+class baseList(Index,setBase,listBase):
     """
     This class the list of index.
     """
+    elementClass = index
     def __init__(self):
         self.all = []
+        self.listType = 'Index List'
         self.__init_get_item__()
 
     def addIndexList(self,indexObjList:list):
